ConnectionManager class

Process-wide registry of live connections keyed by name.

Constructors

ConnectionManager()
factory

Properties

alerts Stream<DatabaseAlert>
no setter
connectionMap Map<String, DatabaseConnection>
getter/setter pair
defaultConnection String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isConnected bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(DBConfig config, String connectionName) Future<void>
connection([String? connectionName]) DatabaseConnection?
getPerformanceStats() Map<String, PerformanceStats>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
transaction(Future<bool> action(), [String? connectionName]) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited