DatabaseConnectionFactory class

The single, process-global driver registry.

Constructors

DatabaseConnectionFactory()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createConnection(DBConfig config) DatabaseConnection
debugClear() → void
isRegistered(String driver) bool
register(String driver, DatabaseConnectionBuilder builder, {List<String> aliases = const []}) → void