DatabaseConnectionProxy class

Wraps a driver-provided DatabaseConnection and records timing + alerts through the shared DatabaseMonitor.

Implemented types

Constructors

DatabaseConnectionProxy(DatabaseConnection _connection, String _connectionId, DatabaseMonitor _monitor)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
underlyingConnection DatabaseConnection
no setter

Methods

close() Future<void>
override
connect() Future<void>
override
execute(String query, [Map<String, dynamic> bindings = const {}]) Future<bool>
override
insert(String query, [Map<String, dynamic> bindings = const {}]) Future
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
select(String query, [Map<String, dynamic> bindings = const {}]) Future<List<Map<String, dynamic>>>
override
toString() String
A string representation of this object.
inherited
transaction<T>(Future<T> action()) Future<T>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited