ForeignKeyBlueprint class

Constructors

ForeignKeyBlueprint({required String columnName, required String referencesTable, required String referencesColumn, String onUpdate = 'CASCADE', String onDelete = 'CASCADE', bool constrained = true})
const

Properties

columnName String
final
constrained bool
final
hashCode int
The hash code for this object.
no setterinherited
onDelete String
final
onUpdate String
final
referencesColumn String
final
referencesTable String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited