MigrationConnection class
- Implemented types
Constructors
- MigrationConnection()
-
factory
Properties
- adapter → DatabaseAdapterInterface?
-
no setter
- connection → DatabaseConnection?
-
no setteroverride
- driver → String?
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
closeConnection(
) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setup(
Map< String, dynamic> databaseConfig) → Future<void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
truncateMigration(
) → Future< void> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited