resetWindowState method
- @protected
inherited
Hook for QueryBuilder.resetQuery; the list is private to this library, so the reset has to be driven from here.
Implementation
@protected
void resetWindowState() => _windowFunctions.clear();
Hook for QueryBuilder.resetQuery; the list is private to this library, so the reset has to be driven from here.
@protected
void resetWindowState() => _windowFunctions.clear();