parentForeignKey property

String get parentForeignKey

The conventional foreign key pointing at the parent, used when the relation was declared without an explicit foreignKey.

Implementation

String get parentForeignKey =>
    '${toSnakeCase(parent.runtimeType.toString())}_id';