Schema class
- Implemented types
- Available extensions
Constructors
- Schema()
Properties
-
columns
→ List<
ColumnBlueprint> -
no setter
-
foreignKeys
→ List<
String> -
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
indexes
→ List<
String> -
no setteroverride
- primaryAlgorithm → String
-
no setteroverride
- primaryField → String
-
no setteroverride
-
queries
→ List<
String> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tableName → String
-
no setter
Methods
-
addColumn(
String name, String type, {bool nullable = false, dynamic length, bool unsigned = false, bool zeroFill = false, dynamic defaultValue, String? comment, String? collation, String? expression, String? virtuality, bool increment = false, bool unique = false}) → void -
override
-
addColumnBlueprint(
ColumnBlueprint blueprint) → void -
addCompositeIndex(
String indexName, String columnName, ColumnIndex type) → void -
addCompositeUniqueConstraint(
String constraintName, List< String> columns) → void -
bigIncrements(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
bigInt(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
binary(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
bit(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
blob(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
boolean(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
char(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
date(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
dateTime(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
decimal(
String name, {int? precision, int? scale}) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
double(
String name, {int? precision, int? scale}) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
enumType(
String name, List< String> values) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
float(
String name, {int? precision, int? scale}) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
foreign(
String columnName, String referencesTable, String referencesColumn, {bool constrained = true, String onUpdate = 'CASCADE', String onDelete = 'CASCADE'}) → void -
override
-
generateDropTableSql(
String tableName, {bool ifExists = false}) → String -
geometry(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
geometryCollection(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
id(
[String name = 'id']) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
index(
ColumnIndex type, String name, List< String> columns) → void -
override
-
integer(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
ipAddress(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
json(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
lineString(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
longBlob(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
longText(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
macAddress(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
mediumBlob(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
mediumInt(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
mediumText(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
multiLineString(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
multiPoint(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
multiPolygon(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
point(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
polygon(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
primary(
String columnName, [String algorithm = 'BTREE']) → void -
override
-
registerColumnDefinition(
dynamic columnDefinition) → void -
reset(
) → void -
override
-
setTableName(
String tableName) → void -
setType(
String name, List< String> values) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
smallInt(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
softDeletes(
[String name = 'deleted_at']) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
string(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
text(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
time(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
timeStamp(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
timeStamps(
) → void -
Available on Schema, provided by the ColumnTypes extension
-
tinyBlob(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
tinyInt(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
tinyText(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
toBlueprint(
) → TableBlueprint -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
uuid(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
varBinary(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
-
year(
String name) → ColumnDefinition -
Available on Schema, provided by the ColumnTypes extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited