SchemaInterface class abstract

Implementers

Constructors

SchemaInterface()

Properties

foreignKeys List<String>
no setter
hashCode int
The hash code for this object.
no setterinherited
indexes List<String>
no setter
primaryAlgorithm String
no setter
primaryField String
no setter
queries List<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addColumn(String name, String type, {bool nullable = false, dynamic length, bool unsigned = false, bool zeroFill = false, dynamic defaultValue, String? comment, String? collation, String? expression, String? virtuality, bool increment = false, bool unique = false}) → void
foreign(String columnName, String referencesTable, String referencesColumn, {bool constrained = true, String onUpdate = 'CASCADE', String onDelete = 'CASCADE'}) → void
index(ColumnIndex type, String name, List<String> columns) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
primary(String columnName, [String algorithm = 'BTREE']) → void
reset() → void
toBlueprint() TableBlueprint
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited