Next typedef
Next =
Future<void> Function()
Continues the middleware chain. Returns once every remaining middleware and the controller have finished.
Implementation
typedef Next = Future<void> Function();
Continues the middleware chain. Returns once every remaining middleware and the controller have finished.
typedef Next = Future<void> Function();