Address class

Constructors

Address(String mailAddress, [String? name])
const

Properties

encodedAddress String
Returns the mail address with the domain encoded using IDNA (Punycode).
no setter
hashCode int
The hash code for this object.
no setterinherited
mailAddress String
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sanitizedName String?
The name used to output to SMTP server. Implementation can override it to pre-process the name before sending. For example, providing a default name for certain address, or quoting it.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited