ColumnBlueprint class
Constructors
-
ColumnBlueprint({required String name, required ColumnType type, bool nullable = true, int? length, int? precision, int? scale, bool unsigned = false, bool zeroFill = false, dynamic defaultValue, String? comment, String? collation, String? charset, String? expression, String? virtuality, bool autoIncrement = false, bool unique = false, List<
String> ? enumValues, List<String> ? setValues}) -
const
Properties
- autoIncrement → bool
-
final
- charset → String?
-
final
- collation → String?
-
final
- comment → String?
-
final
- defaultValue → dynamic
-
final
-
enumValues
→ List<
String> ? -
final
- expression → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int?
-
final
- name → String
-
final
- nullable → bool
-
final
- precision → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → int?
-
final
-
setValues
→ List<
String> ? -
final
- type → ColumnType
-
final
- unique → bool
-
final
- unsigned → bool
-
final
- virtuality → String?
-
final
- zeroFill → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited