ColumnDefinition class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
autoIncrement(
) → ColumnDefinition -
charset(
String charset) → ColumnDefinition -
collate(
String collation) → ColumnDefinition -
comment(
String comment) → ColumnDefinition -
defaultTo(
dynamic value) → ColumnDefinition -
defaultToCurrent(
) → ColumnDefinition -
finalize(
) → void -
foreignKey(
String referencesTable, String referencesColumn, {String onUpdate = 'CASCADE', String onDelete = 'CASCADE'}) → ColumnDefinition -
generated(
String expression, {String virtuality = 'VIRTUAL'}) → ColumnDefinition -
index(
[String? indexName, ColumnIndex type = ColumnIndex.indexKey]) → ColumnDefinition -
length(
int length) → ColumnDefinition -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notNull(
) → ColumnDefinition -
nullable(
) → ColumnDefinition -
toString(
) → String -
A string representation of this object.
inherited
-
unique(
[String? constraintName]) → ColumnDefinition -
unsigned(
) → ColumnDefinition -
zeroFill(
) → ColumnDefinition
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited