ColumnType enum
Values
- bigInt → const ColumnType
- integer → const ColumnType
- tinyInt → const ColumnType
- smallInt → const ColumnType
- mediumInt → const ColumnType
- float → const ColumnType
- double → const ColumnType
- decimal → const ColumnType
- varchar → const ColumnType
- char → const ColumnType
- text → const ColumnType
- tinyText → const ColumnType
- mediumText → const ColumnType
- longText → const ColumnType
- json → const ColumnType
- uuid → const ColumnType
- binary → const ColumnType
- varBinary → const ColumnType
- blob → const ColumnType
- tinyBlob → const ColumnType
- mediumBlob → const ColumnType
- longBlob → const ColumnType
- date → const ColumnType
- time → const ColumnType
- year → const ColumnType
- dateTime → const ColumnType
- timestamp → const ColumnType
- point → const ColumnType
- lineString → const ColumnType
- polygon → const ColumnType
- geometry → const ColumnType
- multiPoint → const ColumnType
- multiLineString → const ColumnType
- multiPolygon → const ColumnType
- geometryCollection → const ColumnType
- enumType → const ColumnType
- setType → const ColumnType
- boolean → const ColumnType
- bit → const ColumnType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ColumnType> - A constant List of the values in this enum, in order of their declaration.