DBConfig class
Configuration payload passed from application boot to a driver's connection builder.
Constructors
- DBConfig({required String driver, String host = 'localhost', int port = 3306, String username = 'root', String password = '', String database = 'vania', String? timezone, String? filePath, bool sslMode = false, bool openInMemorySQLite = false, String collation = 'utf8mb4_general_ci', String? schema, bool pool = false, int poolSize = 2})
Properties
- collation → String
-
final
- database → String
-
final
- driver → String
-
final
- filePath → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String
-
final
- openInMemorySQLite → bool
-
final
- password → String
-
final
- pool → bool
-
final
- poolSize ↔ int
-
getter/setter pair
- port → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schema → String?
-
final
- sslMode → bool
-
final
- timezone ↔ String?
-
getter/setter pair
- username → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited