The connection contract every driver must satisfy.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< void> -
connect(
) → Future< void> -
execute(
String query, [Map< String, dynamic> bindings = const {}]) → Future<bool> -
insert(
String query, [Map< String, dynamic> bindings = const {}]) → Future -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
select(
String query, [Map< String, dynamic> bindings = const {}]) → Future<List< Map< >String, dynamic> > -
toString(
) → String -
A string representation of this object.
inherited
-
transaction<
T> (Future< T> action()) → Future<T>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited