TableBlueprint class
Constructors
-
TableBlueprint({required String tableName, List<
ColumnBlueprint> columns = const [], String? primaryKey, String primaryAlgorithm = 'BTREE', List<IndexBlueprint> indexes = const [], List<ForeignKeyBlueprint> foreignKeys = const [], List<UniqueConstraintBlueprint> uniqueConstraints = const []}) -
const
Properties
-
columns
→ List<
ColumnBlueprint> -
final
-
foreignKeys
→ List<
ForeignKeyBlueprint> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
indexes
→ List<
IndexBlueprint> -
final
- primaryAlgorithm → String
-
final
- primaryKey → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tableName → String
-
final
-
uniqueConstraints
→ List<
UniqueConstraintBlueprint> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited